X-Git-Url: https://scm.cri.ensmp.fr/git/linpy.git/blobdiff_plain/9b755b94aa2c8847ffca607de239f5c3bca9984b..064e82c1b36bfdef47a5bcbbbf7757c7b9adea91:/setup.py
diff --git a/setup.py b/setup.py
index f72af50..4f3fd3b 100755
--- a/setup.py
+++ b/setup.py
@@ -2,31 +2,32 @@
# Copyright 2014 MINES ParisTech
#
# This file is part of Linpy.
#
# Linpy is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Linpy is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Linpy. If not, see .
from distutils.core import setup, Extension
setup(
- name='pypol',
+ name='LinPy',
description='A polyhedral library based on ISL',
author='MINES ParisTech',
- packages=['pypol'],
+ url='https://scm.cri.ensmp.fr/git/linpy.git',
+ packages=['linpy'],
ext_modules = [
- Extension('pypol._islhelper',
- sources=['pypol/_islhelper.c'],
+ Extension('linpy._islhelper',
+ sources=['linpy/_islhelper.c'],
libraries=['isl'])
]
)
@@ -2,31 +2,32 @@
# Copyright 2014 MINES ParisTech
#
-# This file is part of Linpy.
+# This file is part of LinPy.
#
@@ -2,31 +2,32 @@
#
-# Linpy is free software: you can redistribute it and/or modify
+# LinPy is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
@@ -2,31 +2,32 @@
# (at your option) any later version.
#
-# Linpy is distributed in the hope that it will be useful,
+# LinPy is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
@@ -2,31 +2,32 @@
#
# You should have received a copy of the GNU General Public License
-# along with Linpy. If not, see .
+# along with LinPy. If not, see .
from distutils.core import setup, Extension
setup(